# Just: _Trading Bot_

Just a Trading Bot Algorithm and Simple Server.

## Features

## License

This project was licensed under the terms of the [MIT license](LICENSE), and thanks
all for reference public blogs that sharing knowledge to me.
